@@ -16,10 +16,10 @@ from ..copyable import Copyable
 
 class Location():
     """
-    A `Location` defines at which base(s)/residue(s) a feature is
+    A :class:`Location` defines at which base(s)/residue(s) a feature is
     located.
     
-    A feature can have multiple `Location` instances if multiple
+    A feature can have multiple :class:`Location` instances if multiple
     locations are joined.
 
     Objects of this class are immutable.
@@ -31,8 +31,8 @@ class Location():
     last : int
         Inclusive ending base or residue position of the feature.
     strand : Strand
-        The strand direction. Always `Strand.FORWARD` for peptide
-        features.
+        The strand direction.
+        Always :attr:`Strand.FORWARD` for peptide features.
     defect : Defect
         A possible defect of the location.
     """
@@ -46,18 +46,18 @@ class Location():
         
            - **NONE** - No location defect
            - **MISS_LEFT** - A part of the feature has been truncated
-             before the first base/residue of the `Location`
-             (probably by indexing an `Annotation` object)
+             before the first base/residue of the :class:`Location`
+             (probably by indexing an :class:`Annotation` object)
            - **MISS_RIGHT** - A part of the feature has been truncated
-             after the last base/residue of the `Location`
-             (probably by indexing an `Annotation` object)
+             after the last base/residue of the :class:`Location`
+             (probably by indexing an :class:`Annotation` object)
            - **BEYOND_LEFT** - The feature starts at an unknown position
-             before the first base/residue of the `Location`
+             before the first base/residue of the :class:`Location`
            - **BEYOND_RIGHT** - The feature ends at an unknown position
-             after the last base/residue of the `Location`
+             after the last base/residue of the :class:`Location`
            - **UNK_LOC** - The exact position is unknown, but it is at a
              single base/residue between the first and last residue of
-             the `Location`, inclusive
+             the :class:`Location`, inclusive
            - **BETWEEN** - The position is between to consecutive
              bases/residues.
         """
@@ -245,46 +245,50 @@ class Feature(Copyable):
 
 class Annotation(Copyable):
     """
-    An `Annotation` is a set of features belonging to one sequence.
+    An :class:`Annotation` is a set of features belonging to one
+    sequence.
     
     Its advantage over a simple list is the base/residue position based
     indexing:
     When using slice indices in Annotation objects, a subannotation is
-    created, containing copies of all `Feature` objects whose first and
-    last base/residue are in range of the slice.
+    created, containing copies of all :class:`Feature` objects whose
+    first and last base/residue are in range of the slice.
     If the slice starts after the first base/residue or/and the slice
     ends before the last residue, the position out of range is set to
-    the boundaries of the slice (the `Feature` is truncated). In this
-    case the `Feature` obtains the `MISS_LEFT` and/or `MISS_RIGHT`
-    defect.
-    The third case occurs when a `Feature` starts after the slice ends
-    or a `Feature` ends before the slice starts. In this case the
-    `Feature` will not appear in the subannotation.
+    the boundaries of the slice (the :class:`Feature` is truncated).
+    In this case the :class:`Feature` obtains the
+    :attr:`Location.Defect.MISS_LEFT` and/or
+    :attr:`Location.Defect.MISS_RIGHT` defect.
+    The third case occurs when a :class:`Feature` starts after the slice
+    ends or a :class:`Feature` ends before the slice starts.
+    In this case the :class:`Feature` will not appear in the
+    subannotation.
     
     The start or stop position in the slice indices can be omitted, then
     the subannotation will include all features from the start or up to
     the stop, respectively. Step values are ignored.
     The stop values are still exclusive, i.e. the subannotation will
-    contain a not truncated `Feature` only if its last base/residue is
-    smaller than the stop value of the slice.
+    contain a not truncated :class:`Feature` only if its last
+    base/residue is smaller than the stop value of the slice.
     
     Integers or other index types are not supported. If you want to
-    obtain the `Feature` instances from the `Annotation` you need to 
-    iterate over it. The iteration has no defined order.
-    Alternatively, you can obtain a copy of the internal `Feature` set
-    via `get_features()`.
+    obtain the :class:`Feature` instances from the :class:`Annotation`
+    you need to  iterate over it.
+    The iteration has no defined order.
+    Alternatively, you can obtain a copy of the internal
+    :class:`Feature` set via :func:`get_features()`.
     
-    Multiple `Annotation` objects can be concatenated to one
-    `Annotation` object using the '+' operator. Single `Feature`
-    instances can be added this way, too. If a feature is present
-    in both `Annotation` objects, the resulting `Annotation` will
-    contain this feature twice.
+    Multiple :class:`Annotation` objects can be concatenated to one
+    :class:`Annotation` object using the '+' operator.
+    Single :class:`Feature` instances can be added this way, too.
+    If a feature is present in both :class:`Annotation` objects, the
+    resulting :class:`Annotation` will contain this feature twice.
     
     Parameters
     ----------
     features : iterable object of Feature, optional
-        The features to create the `Annotation` from. if not
-        provided, an empty `Annotation` is created.
+        The features to create the :class:`Annotation` from. if not
+        provided, an empty :class:`Annotation` is created.
     
     Examples
     --------
@@ -491,37 +495,41 @@ class Annotation(Copyable):
 
 class AnnotatedSequence(Copyable):
     """
-    An `AnnotatedSequence` is a combination of a `Sequence` and an
-    `Annotation`.
+    An :class:`AnnotatedSequence` is a combination of a
+    :class:`Sequence` and an :class:`Annotation`.
     
-    Indexing an `AnnotatedSequence` with a slice returns another
-    `AnnotatedSequence` with the corresponding subannotation and a
-    sequence start corrected subsequence, i.e. indexing starts at 1 with
-    the default sequence start 1. The sequence start in the newly
-    created `AnnotatedSequence` is the start of the slice.
+    Indexing an :class:`AnnotatedSequence` with a slice returns another
+    :class:`AnnotatedSequence` with the corresponding subannotation and
+    a sequence start corrected subsequence, i.e. indexing starts at 1
+    with the default sequence start 1.
+    The sequence start in the newly created :class:`AnnotatedSequence`
+    is the start of the slice.
     Furthermore, integer indices are allowed in which case the
     corresponding symbol of the sequence is returned (also sequence
     start corrected).
     In both cases the index must be in range of the sequence, e.g. if
     sequence start is 1, index 0 is not allowed.
     Negative indices do not mean indexing from the end of the sequence,
-    in contrast to the behavior in `Sequence` objects.
+    in contrast to the behavior in :class:`Sequence` objects.
     Both index types can also be used to modify the sequence.
     
-    Another option is indexing with a `Feature` (preferably from the
-    `Annotation` in the same `AnnotatedSequence`). In this case a
-    sequence, described by the location(s) of the `Feature`, is
-    returned.
-    When using a `Feature` for setting an `AnnotatedSequence` with a
-    sequence, the new sequence is replacing the locations of the
-    `Feature`. It is important to note that the sum of the location's 
-    interval lengths must fit the length of the replacing sequence.
-        
+    Another option is indexing with a :class:`Feature` (preferably from the
+    :class:`Annotation` in the same :class:`AnnotatedSequence`).
+    In this case a sequence, described by the location(s) of the
+    :class:`Feature`, is returned.
+    When using a :class:`Feature` for setting an
+    :class:`AnnotatedSequence` with a sequence, the new sequence is
+    replacing the locations of the
+    :class:`Feature`.
+    Note the the replacing sequence must have the same length as the
+    sequence of the :class:`Feature` index.
+    
     Parameters
     ----------
     sequence : Sequence
-        The sequence. Usually a `NucelotideSequence` or
-        `ProteinSequence`.
+        The sequence.
+        Usually a :class:`NucleotideSequence` or
+        :class:`ProteinSequence`.
     annotation : Annotation
         The annotation corresponding to `sequence`.
     sequence_start : int, optional
