@@ -16,6 +16,7 @@ import numpy as np
 from .atoms import Atom, AtomArray, AtomArrayStack, coord
 from .util import vector_dot, norm_vector
 from .filter import filter_backbone
+from .chains import chain_iter
 from .box import (coord_to_fraction, fraction_to_coord,
                   move_inside_box, is_orthogonal)
 from .error import BadStructureError
@@ -146,8 +147,8 @@ def index_displacement(*args, **kwargs):
     displacement should be calculated.
     If an atom array stack is provided, the distances are calculated for
     each frame/model.
-    In contrast to the `distance()` function, this function is able
-    to take periodic boundary conditions into account.
+    In contrast to the :func:`distance()` function, this function is
+    able to take periodic boundary conditions into account.
 
     Parameters
     ----------
@@ -155,7 +156,7 @@ def index_displacement(*args, **kwargs):
         The atoms the `indices` parameter refers to.
         The pairwise distances are calculated for these pairs.
         Alternatively, the atom coordinates can be directly provided as
-        `ndarray`.
+        :class:`ndarray`.
     indices : ndarray, shape=(k,2)
         Pairs of indices that point to `atoms`.
         The displacement is measured from ``indices[x,0]`` to 
@@ -239,8 +240,8 @@ def index_distance(*args, **kwargs):
     distances should be calculated.
     If an atom array stack is provided, the distances are calculated for
     each frame/model.
-    In contrast to the `distance()` function, this function is able
-    to take periodic boundary conditions into account.
+    In contrast to the :func:`distance()` function, this function is
+    able to take periodic boundary conditions into account.
 
     Parameters
     ----------
@@ -248,7 +249,7 @@ def index_distance(*args, **kwargs):
         The atoms the `indices` parameter refers to.
         The pairwise distances are calculated for these pairs.
         Alternatively, the atom coordinates can be directly provided as
-        `ndarray`.
+        :class:`ndarray`.
     indices : ndarray, shape=(k,2)
         Pairs of indices that point to `atoms`.
     periodic : bool, optional
@@ -337,7 +338,7 @@ def index_angle(*args, **kwargs):
         The atoms the `indices` parameter refers to.
         The triplewise distances are calculated for these pairs.
         Alternatively, the atom coordinates can be directly provided as
-        `ndarray`.
+        :class:`ndarray`.
     indices : ndarray, shape=(k,3)
         Triples of indices that point to `atoms`.
     periodic : bool, optional
@@ -438,7 +439,7 @@ def index_dihedral(*args, **kwargs):
         The quadruplewise dihedral angles are calculated for these
         pairs.
         Alternatively, the atom coordinates can be directly provided as
-        `ndarray`.
+        :class:`ndarray`.
     indices : ndarray, shape=(k,4)
         Quadruples of indices that point to `atoms`.
     periodic : bool, optional
@@ -477,7 +478,7 @@ def index_dihedral(*args, **kwargs):
     return _call_non_index_function(dihedral, 4, *args, **kwargs)
 
 
-def dihedral_backbone(atom_array, chain_id):
+def dihedral_backbone(atom_array):
     """
     Measure the characteristic backbone dihedral angles of a structure.
     
@@ -486,9 +487,10 @@ def dihedral_backbone(atom_array, chain_id):
     atom_array: AtomArray or AtomArrayStack
         The protein structure. A complete backbone, without gaps,
         is required here.
-    chain_id: string
-        The ID of the polypeptide chain. The dihedral angles are
-        calculated for ``atom_array[atom_array.chain_id == chain_id]``
+        Chain transitions are allowed, the angles at the transition are
+        `NaN`.
+        The order of the backbone atoms for each residue must be
+        (N, CA, C).
     
     Returns
     -------
@@ -496,9 +498,9 @@ def dihedral_backbone(atom_array, chain_id):
         An array containing the 3 backbone dihedral angles for every
         CA. 'phi' is not defined at the N-terminus, 'psi' and 'omega'
         are not defined at the C-terminus. In these places the arrays
-        have `NaN` values. If an `AtomArrayStack` is given, the output
-        angles are 2-dimensional, the first dimension corresponds to
-        the model number.
+        have *NaN* values. If an :class:`AtomArrayStack` is given, the
+        output angles are 2-dimensional, the first dimension corresponds
+        to the model number.
     
     Raises
     ------
@@ -513,8 +515,8 @@ def dihedral_backbone(atom_array, chain_id):
     Examples
     --------
     
-    >>> phi, psi, omega = dihedral_backbone(atom_array, "A")
-    >>> print(np.stack([phi * 360/(2*np.pi), psi * 360/(2*np.pi)]).T)
+    >>> phi, psi, omega = dihedral_backbone(atom_array)
+    >>> print(np.stack([np.rad2deg(phi), np.rad2deg(psi)]).T)
     [[     nan  -56.145]
      [ -43.980  -51.309]
      [ -66.466  -30.898]
@@ -536,24 +538,40 @@ def dihedral_backbone(atom_array, chain_id):
      [ -77.264  124.223]
      [ -78.100      nan]]
     """
-    # Filter all backbone atoms
-    bb_coord = atom_array[...,
-                            filter_backbone(atom_array) &
-                            (atom_array.chain_id == chain_id)].coord
-    if bb_coord.shape[-1] % 3 != 0:
-        raise BadStructureError(
-            "AtomArray has insufficient amount of backbone atoms "
-            "(possibly missing terminus)"
-        )
+    bb_filter = filter_backbone(atom_array)
+    backbone = atom_array[..., bb_filter]
     
+    if backbone.array_length() % 3 != 0 \
+        or (backbone.atom_name[0::3] != "N" ).any() \
+        or (backbone.atom_name[1::3] != "CA").any() \
+        or (backbone.atom_name[2::3] != "C" ).any():
+            raise BadStructureError(
+                "The backbone is invalid, must be repeats of (N, CA, C), "
+                "maybe a backbone atom is missing"
+            )
+    phis = []
+    psis = []
+    omegas = []
+    for chain_bb in chain_iter(backbone):
+        phi, psi, omega = _dihedral_backbone(chain_bb)
+        phis.append(phi)
+        psis.append(psi)
+        omegas.append(omega)
+    return np.concatenate(phis, axis=-1), np.concatenate(psis, axis=-1), \
+        np.concatenate(omegas, axis=-1)
+
+
+
+def _dihedral_backbone(chain_bb):
+    bb_coord = chain_bb.coord
     # Coordinates for dihedral angle calculation
     # Dim 0: Model index (only for atom array stacks)
     # Dim 1: Angle index
     # Dim 2: X, Y, Z coordinates
     # Dim 3: Atoms involved in dihedral angle
-    if isinstance(atom_array, AtomArray):
+    if isinstance(chain_bb, AtomArray):
         angle_coord_shape = (len(bb_coord)//3, 3, 4)
-    elif isinstance(atom_array, AtomArrayStack):
+    elif isinstance(chain_bb, AtomArrayStack):
         angle_coord_shape = (bb_coord.shape[0], bb_coord.shape[1]//3, 3, 4)
     phi_coord   = np.full(angle_coord_shape, np.nan)
     psi_coord   = np.full(angle_coord_shape, np.nan)
@@ -598,8 +616,8 @@ def centroid(atoms):
     Returns
     -------
     centroid : float or ndarray
-        The centroid of the structure(s). `ndarray` is returned when
-        an `AtomArrayStack` is given (centroid for each model).
+        The centroid of the structure(s). :class:`ndarray` is returned when
+        an :class:`AtomArrayStack` is given (centroid for each model).
     """
     return np.mean(coord(atoms), axis=-2)
 
