@@ -6,8 +6,8 @@
 A subpackage for reading and writing structure related data.
 
 Macromolecular structure files (PDB, PDBx/mmCIF, MMTF) can be used to
-load an `AtomArray` or `AtomArrayStack`.
-Since the data model for the `AtomArray` and `AtomArrayStack` class does
+load an :class:`AtomArray` or :class:`AtomArrayStack`.
+Since the data model for the :class:`AtomArray` and :class:`AtomArrayStack` class does
 not support dublicate atoms, only one *altloc* or *insertion code* can
 be chosen for each residue. Hence, the amount of atoms may be lower
 in the atom array (stack) than in respective structure file.
@@ -15,7 +15,7 @@ in the atom array (stack) than in respective structure file.
 The recommended format for reading structure files is MMTF.
 It has by far the shortest parsing time and file size.
 Furthermore, chemical bond information can be read from MMTF files
-as `BondList` instances.
+as :class:`BondList` instances.
 
 Besides the mentioned structure formats, Gromacs trajectory files can be
 loaded, if `mdtraj` is installed.
